#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-K4opOdV0WXw9pUNcZU8d5S
key:                  svg-builder-0.1.1-K4opOdV0WXw9pUNcZU8d5S
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  e9b892e89db1309fdef17d1cfde4948b
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-9.6.6/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/svg-builder-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-svg-builder
hs-libraries:         HSsvg-builder-0.1.1-K4opOdV0WXw9pUNcZU8d5S
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-9Evz8oerfDZ9EQvA8PZ07a
    bytestring-0.11.5.3 hashable-1.4.7.0-8JCT2FqI0OIc7eryHiY9E
    text-2.0.2 unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

